import uvicore
from uvicore.events import Handler
from uvicore.support.dumper import dump, dd
from uvicore.foundation.events import app as AppEvents
from uvicore.contracts import Package as Package
from uvicore.console import command_is
from starlette.applications import Starlette as _Starlette
from fastapi import FastAPI as _FastAPI
from uvicore.http import response
from uvicore.http.events import server as HttpServerEvents


class Cache(Handler):

    def __call__(self, event: AppEvents.Registered):
        """Bootstrap the Cache system after the Application is Registered"""



        dump('cache bootstrap')



import uvicore
from uvicore.support.dumper import dump, dd
from starlette.concurrency import run_in_threadpool


# Does not work as I need it to
# from asgiref.sync import async_to_sync
# def asyncmethodOBSOLETE_TEST(func):
#     """Convert an async method into a sync method if running synchronously"""
#     def decorator(*args, **kwargs):
#         do_async = False

#         if do_async == False:
#         #if not uvicore.app.is_async:
#             # If NOT running async (so from CLI) convert all async calls to sync
#             value = async_to_sync(func)(*args, **kwargs)



#             # if async_to_sync.launch_map:
#             #     # Event loop already exists, call function asynchronously
#             #     dump(async_to_sync.__dict__)
#             #     value = func(*args, **kwargs)
#             # else:
#             #     # No event loop started, create a new one
#             #     value = async_to_sync(func)(*args, **kwargs)

#             # try:
#             #     #dump(async_to_sync.__dict__)
#             #     value = async_to_sync(func)(*args, **kwargs)
#             # except RuntimeError:
#             #     # Exception means event loop is already running
#             #     # So don't async_to_sync again or you get RuntimeError
#             #     # "You cannot use AsyncToSync in the same thread as an async event loop - "
#             #     # "just await the async function directly."
#             #     value = func(*args, **kwargs)
#         else:
#             # If running async, call async func normally
#             value = func(*args, **kwargs)
#         return value
#     return decorator



from uvicore.support.dumper import dump, dd
from uvicore.support.module import location
from uvicore.database import Connection
from uvicore.typing import Dict, List


class Redis:
    """Redis Service Provider Mixin"""

    def redis_connections(self, connections: Dict, default: str):
        self.package.redis.connections = connections
        self.package.redis.connection_default = default

